#
# spec file for package physfs
#
# Copyright (c) 2016 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%define so_nr 1
%define desc "PhysicsFS is a library to provide abstract access to various archives.\
It is intended for use in video games, and the design was somewhat\
inspired by Quake 3's file subsystem. The programmer defines a "write\
directory" on the physical filesystem. No file writing done through the\
PhysicsFS API can leave that write directory, for security. For\
example, an embedded scripting language cannot write outside of this\
path if it uses PhysFS for all of its I/O, which means that untrusted\
scripts can run more safely. Symbolic links can be disabled as well,\
for added safety. For file reading, the programmer lists directories\
and archives that form a "search path". Once the search path is\
defined, it becomes a single, transparent hierarchical filesystem. This\
makes for easy access to ZIP files in the same way as you access a file\
directly on the disk, and it makes it easy to ship a new archive that\
will override a previous archive on a per-file basis. Finally,\
PhysicsFS gives you platform-abstracted means to determine if CD-ROMs\
are available, the user's home directory, where in the real filesystem\
your program is running, etc."\

Name:           physfs
Version:        2.0.3
Release:        180.1
Summary:        PhysicsFS file abstraction layer for games
License:        (LGPL-2.1+ or CPL-1.0) and Zlib
Group:          System/Libraries
Url:            http://www.icculus.org/physfs/
Source:         http://icculus.org/physfs/downloads/%{name}-%{version}.tar.bz2
BuildRequires:  cmake
BuildRequires:  gcc-c++
BuildRequires:  zlib-devel
BuildRequires:  pkgconfig
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
%{desc}

%package -n lib%{name}%{so_nr}
Summary:        PhysicsFS file abstraction layer for games
Group:          System/Libraries
# physfs was last used in openSUSE 11.3
Provides:       physfs = %{version}
Obsoletes:      physfs <= 1.0.1

%description -n lib%{name}%{so_nr}
%{desc}

%package -n lib%{name}-devel
Summary:        Libraries, includes and more to develop PhysicsFS applications
Group:          Development/Libraries/C and C++
Requires:       lib%{name}%{so_nr} = %{version}
# physfs-devel was last used in openSUSE 11.3
Provides:       physfs-devel = %{version}
Obsoletes:      physfs-devel <= 1.0.1

%description -n lib%{name}-devel
%{desc}

%prep
%setup -q

%build
# just to be sure...
rm -rf zlib123
%cmake \
  -DCMAKE_BUILD_TYPE=Release \
  -DPHYSFS_BUILD_STATIC=FALSE \
  -DPHYSFS_BUILD_TEST=FALSE
make %{?_smp_mflags}

%install
%cmake_install

install -d %{buildroot}%{_libdir}/pkgconfig
cat << EOF > %{buildroot}%{_libdir}/pkgconfig/%{name}.pc
prefix=%{_prefix}
exec_prefix=\${prefix}
libdir=\${exec_prefix}/%{_lib}
includedir=\${prefix}/include

Name: PhysicsFS
Description: PhysicsFS, a library to provide abstract access to various archives
URL: %{url}
Version: %{version}
Libs: -L\${libdir} -lphysfs
Cflags: -I\${includedir}
EOF

%post -n lib%{name}%{so_nr} -p /sbin/ldconfig

%postun -n lib%{name}%{so_nr} -p /sbin/ldconfig

%files -n lib%{name}%{so_nr}
%defattr(0644,root,root,0755)
%doc CREDITS.txt INSTALL.txt LICENSE.txt TODO.txt
%{_libdir}/libphysfs.so.%{so_nr}
%{_libdir}/libphysfs.so.%{version}

%files -n lib%{name}-devel
%defattr(0644,root,root,0755)
%{_libdir}/libphysfs.so
%{_includedir}/physfs.h
%{_libdir}/pkgconfig/%{name}.pc

%changelog
* Sat Aug 20 2016 mailaender@opensuse.org
- Add a pkgconfig file
* Wed Feb 10 2016 mpluskal@suse.com
- Use cmake macros
* Tue Nov 26 2013 speilicke@suse.com
- Remove physfs-2.0.2-gcc46.patch (merged upstream)
* Fri Nov 15 2013 mailaender@opensuse.org
- Source code now packaged in a .tar.bz2 instead of .tar.gz.
- Fixed "make docs" for out-of-tree builds.
- No longer builds annoying wxWidgets test program by default.
- Fixed logic bug in UTF-8 string processing.
- Fixed infinite loop on some .zip files with symlinks.
- Fixed building of readline support in test program.
- Fixed .zip archiver losing files in some cases.
- Corrected copyright dates in license.
- Other minor tweaks and fixes.
* Mon Mar  5 2012 cfarrell@suse.com
- license update: (LGPL-2.1+ or CPL-1.0) and Zlib
  For a license such as this brackets are needed to avoid ambiguity
* Tue Feb 14 2012 coolo@suse.com
- use original tar and avoid _service files
- trying to convert the license to spdx.org
* Sun Apr  3 2011 reddwarf@opensuse.org
- Fix gcc 4.6 compilation
- Use %%optflags
* Mon Feb 21 2011 reddwarf@opensuse.org
- update to version 2.0.2
  * Fixed bug where zip and qpak could fail to locate an existing file.
  * Fixed overflow on zero-sized buffers when converting to UTF-8.
* Wed Feb 16 2011 reddwarf@opensuse.org
- update to version 2.0.1
  * lzma support
  * unicode support
  * improved CD-ROM/DVD-ROM detection
  * API extended with new functions
- use source services
- run spec-cleaner
- follow SLPP
- adapt to new cmake build system
* Fri Mar 13 2009 crrodriguez@suse.de
- remove static libraries and "la" files
- fix rpmlint warnings
- fix -devel package dependencies
* Thu Apr  5 2007 lnussel@suse.de
- build test program with readline support
- install man pages into proper directory
- use %%jobs
* Mon Apr  2 2007 rguenther@suse.de
- add zlib-devel BuildRequires
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Sun Aug 14 2005 sndirsch@suse.de
- created package; useful e.g. for building lincity-ng
